import { LarkServer } from "../../types/larkServer";
import larkNetTool from "./larkNetTool";

/**
 * 登录凭证校验
 * @param code
 * @returns
 */
const code2Session = async (code: string) => {
  const URL = `https://open.f.mioffice.cn/open-apis/mina/v2/tokenLoginValidate`;
  return larkNetTool.post<LarkServer.UserSessionRes>(URL, { code });
};

/**
 * 获取用户信息
 * @param user_id
 * @returns
 */
const getUser = async (user_id: string) => {
  const URL = `https://open.f.mioffice.cn/open-apis/contact/v3/users/${user_id}`;
  return larkNetTool.get<LarkServer.UserInfoRes>(URL, {
    user_id_type: "user_id",
  });
};

/**
 * 批量获取用户信息
 * @param user_ids
 * @returns
 */
const getMultiUser = async (user_ids: string[]) => {
  const URL = `https://open.f.mioffice.cn/open-apis/user/v1/batch_get`;
  return larkNetTool.get<LarkServer.UserInfoRes>(URL, {
    user_ids,
    user_id_type: "user_id",
  });
};

const user = {
  code2Session,
  getMultiUser,
  getUser,
};

export default user;
